/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SamlAuthBackendConfig extends cdktf.TerraformMetaArguments {
    /**
    * The well-formatted URLs of your Assertion Consumer Service (ACS) that should receive a response from the identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#acs_urls SamlAuthBackend#acs_urls}
    */
    readonly acsUrls: string[];
    /**
    * The role to use if no role is provided during login.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#default_role SamlAuthBackend#default_role}
    */
    readonly defaultRole?: string;
    /**
    * If set, opts out of mount migration on path updates.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#disable_remount SamlAuthBackend#disable_remount}
    */
    readonly disableRemount?: boolean | cdktf.IResolvable;
    /**
    * The entity ID of the SAML authentication service provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#entity_id SamlAuthBackend#entity_id}
    */
    readonly entityId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#id SamlAuthBackend#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The PEM encoded certificate of the identity provider. Mutually exclusive with 'idp_metadata_url'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#idp_cert SamlAuthBackend#idp_cert}
    */
    readonly idpCert?: string;
    /**
    * The entity ID of the identity provider. Mutually exclusive with 'idp_metadata_url'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#idp_entity_id SamlAuthBackend#idp_entity_id}
    */
    readonly idpEntityId?: string;
    /**
    * The metadata URL of the identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#idp_metadata_url SamlAuthBackend#idp_metadata_url}
    */
    readonly idpMetadataUrl?: string;
    /**
    * The SSO URL of the identity provider. Mutually exclusive with 'idp_metadata_url'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#idp_sso_url SamlAuthBackend#idp_sso_url}
    */
    readonly idpSsoUrl?: string;
    /**
    * Target namespace. (requires Enterprise)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#namespace SamlAuthBackend#namespace}
    */
    readonly namespace?: string;
    /**
    * Unique name of the auth backend to configure.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#path SamlAuthBackend#path}
    */
    readonly path?: string;
    /**
    * Log additional, potentially sensitive information during the SAML exchange according to the current logging level. Not recommended for production.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#verbose_logging SamlAuthBackend#verbose_logging}
    */
    readonly verboseLogging?: boolean | cdktf.IResolvable;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend vault_saml_auth_backend}
*/
export declare class SamlAuthBackend extends cdktf.TerraformResource {
    static readonly tfResourceType = "vault_saml_auth_backend";
    /**
    * Generates CDKTF code for importing a SamlAuthBackend resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SamlAuthBackend to import
    * @param importFromId The id of the existing SamlAuthBackend that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SamlAuthBackend to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/vault/4.1.0/docs/resources/saml_auth_backend vault_saml_auth_backend} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SamlAuthBackendConfig
    */
    constructor(scope: Construct, id: string, config: SamlAuthBackendConfig);
    private _acsUrls?;
    get acsUrls(): string[];
    set acsUrls(value: string[]);
    get acsUrlsInput(): string[] | undefined;
    private _defaultRole?;
    get defaultRole(): string;
    set defaultRole(value: string);
    resetDefaultRole(): void;
    get defaultRoleInput(): string | undefined;
    private _disableRemount?;
    get disableRemount(): boolean | cdktf.IResolvable;
    set disableRemount(value: boolean | cdktf.IResolvable);
    resetDisableRemount(): void;
    get disableRemountInput(): boolean | cdktf.IResolvable | undefined;
    private _entityId?;
    get entityId(): string;
    set entityId(value: string);
    get entityIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _idpCert?;
    get idpCert(): string;
    set idpCert(value: string);
    resetIdpCert(): void;
    get idpCertInput(): string | undefined;
    private _idpEntityId?;
    get idpEntityId(): string;
    set idpEntityId(value: string);
    resetIdpEntityId(): void;
    get idpEntityIdInput(): string | undefined;
    private _idpMetadataUrl?;
    get idpMetadataUrl(): string;
    set idpMetadataUrl(value: string);
    resetIdpMetadataUrl(): void;
    get idpMetadataUrlInput(): string | undefined;
    private _idpSsoUrl?;
    get idpSsoUrl(): string;
    set idpSsoUrl(value: string);
    resetIdpSsoUrl(): void;
    get idpSsoUrlInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
    private _verboseLogging?;
    get verboseLogging(): boolean | cdktf.IResolvable;
    set verboseLogging(value: boolean | cdktf.IResolvable);
    resetVerboseLogging(): void;
    get verboseLoggingInput(): boolean | cdktf.IResolvable | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
